@@ -110,7 +110,7 @@ class Dsc(debian.deb822.Dsc):
                 if (size != their_checksums[name][0] or
                     checksum != their_checksums[name][1]):
                     return False
-            return True # one checksum is good enough
+            return True  # one checksum is good enough
         return True
 
 
@@ -154,6 +154,10 @@ class SourcePackage(object):
 
         self.version = debian.debian_support.Version(version)
 
+        # uses default proxies from the environment
+        proxy = urllib2.ProxyHandler()
+        self.url_opener = urllib2.build_opener(proxy)
+
     @property
     def lp_spph(self):
         "Return the LP Source Package Publishing History entry"
@@ -318,7 +322,7 @@ class SourcePackage(object):
             in_ = open(parsed.path, 'r')
         else:
             try:
-                in_ = urllib2.urlopen(url)
+                in_ = self.url_opener.open(url)
             except urllib2.URLError:
                 return False
 
@@ -496,7 +500,7 @@ class DebianSourcePackage(SourcePackage):
                                     "python-simplejson")
 
             try:
-                srcfiles = json.load(urllib2.urlopen(
+                srcfiles = json.load(self.url_opener.open(
                     'http://snapshot.debian.org'
                     '/mr/package/%s/%s/srcfiles?fileinfo=1'
                         % (self.source, self.version.full_version)))
@@ -596,13 +600,12 @@ def rmadison(url, package, suite=None, arch=None):
     process = subprocess.Popen(cmd, stdout=subprocess.PIPE,
                                stderr=subprocess.PIPE, close_fds=True)
     output, error_output = process.communicate()
-    try:
-        assert process.wait() == 0
-    except AssertionError:
+    if process.wait() != 0:
         if error_output:
             Logger.error('rmadison failed with: %s', error_output)
-            sys.exit(1)
-        raise
+        else:
+            Logger.error('rmadison failed')
+        sys.exit(1)
 
     # rmadison uses some shorthand
     if suite:
